#[non_exhaustive]pub struct ListWorkGroupsInputBuilder { /* private fields */ }Expand description
A builder for ListWorkGroupsInput.
Implementations
Sourceimpl ListWorkGroupsInputBuilder
impl ListWorkGroupsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of workgroups to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of workgroups to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of workgroups to return in this request.
Sourcepub fn build(self) -> Result<ListWorkGroupsInput, BuildError>
pub fn build(self) -> Result<ListWorkGroupsInput, BuildError>
Consumes the builder and constructs a ListWorkGroupsInput.
Sourceimpl ListWorkGroupsInputBuilder
impl ListWorkGroupsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListWorkGroupsOutput, SdkError<ListWorkGroupsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListWorkGroupsOutput, SdkError<ListWorkGroupsError, HttpResponse>>
Sends a request with this input using the given client.