#[non_exhaustive]pub struct ListWorkGroupsOutputBuilder { /* private fields */ }Expand description
A builder for ListWorkGroupsOutput.
Implementations
Sourceimpl ListWorkGroupsOutputBuilder
impl ListWorkGroupsOutputBuilder
Sourcepub fn work_groups(self, input: WorkGroupSummary) -> Self
pub fn work_groups(self, input: WorkGroupSummary) -> Self
Appends an item to work_groups.
To override the contents of this collection use set_work_groups.
A list of WorkGroupSummary objects that include the names, descriptions, creation times, and states for each workgroup.
Sourcepub fn set_work_groups(self, input: Option<Vec<WorkGroupSummary>>) -> Self
pub fn set_work_groups(self, input: Option<Vec<WorkGroupSummary>>) -> Self
A list of WorkGroupSummary objects that include the names, descriptions, creation times, and states for each workgroup.
Sourcepub fn get_work_groups(&self) -> &Option<Vec<WorkGroupSummary>>
pub fn get_work_groups(&self) -> &Option<Vec<WorkGroupSummary>>
A list of WorkGroupSummary objects that include the names, descriptions, creation times, and states for each workgroup.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> ListWorkGroupsOutput
pub fn build(self) -> ListWorkGroupsOutput
Consumes the builder and constructs a ListWorkGroupsOutput.